==> lxqt-session-0.14.0.tar.xz: lxqt-session-0.14.0/lxqt-leave/translations/lxqt-leave_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation>Meninggalkan</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Apa yang Anda ingin komputer lakukan?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="51"/>
        <source>Logout</source>
        <translation>Keluar log</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="69"/>
        <source>Reboot</source>
        <translation>Muat ulang</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="56"/>
        <source>Shutdown</source>
        <translation>Matikan</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="61"/>
        <source>Suspend</source>
        <translation>Suspensi</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="66"/>
        <source>Lock screen</source>
        <translation>Kunci layar</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="74"/>
        <source>Hibernate</source>
        <translation>Hibernasi</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="51"/>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Logout.</source>
        <translation>Keluar log.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Lockscreen.</source>
        <translation>Kunci layar.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Suspend.</source>
        <translation>Suspensi.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>Hibernate.</source>
        <translation>Hibernasi.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Shutdown.</source>
        <translation>Matikan.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Reboot.</source>
        <translation>Muat ulang.</translation>
    </message>
</context>
</TS>

==> lxqt-session-0.15.0.tar.xz: lxqt-session-0.15.0/lxqt-leave/translations/lxqt-leave_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation>Meninggalkan</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Apa yang anda ingin komputer ini lakukan?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="51"/>
        <source>Logout</source>
        <translation>Keluar</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="69"/>
        <source>Reboot</source>
        <translation>Muat ulang</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="56"/>
        <source>Shutdown</source>
        <translation>Matikan</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="61"/>
        <source>Suspend</source>
        <translation>Suspensi</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="66"/>
        <source>Lock screen</source>
        <translation>Kunci layar</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="74"/>
        <source>Hibernate</source>
        <translation>Hibernasi</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="51"/>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Logout.</source>
        <translation>Keluar.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Lockscreen.</source>
        <translation>Kunci layar.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Suspend.</source>
        <translation>Suspensi.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>Hibernate.</source>
        <translation>Hibernasi.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Shutdown.</source>
        <translation>Matikan.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Reboot.</source>
        <translation>Muat ulang.</translation>
    </message>
</context>
</TS>
